@@ -2,12 +2,19 @@ import decimal
 import json
 from math import sin, cos, sqrt, atan2, radians
 from time import sleep
-
+import os
 from botocore.exceptions import ClientError
 from dateutil.parser import parse
+import boto3
 
-from settings import dynamodb_resource as dynamodb
+from properly_util_python.dynamo_helper import DynamoHelperBase, EnvironmentControlledDynamoHelper
 
+
+#consider: avoid file scope?
+s3 = boto3.resource('s3',)
+
+
+import traceback
 COLUMN_NAME_MAPPING = {
     "Bedrms": "bedrooms",
     "Bedrms Above Grade": "bedroomsAG",
@@ -60,6 +67,8 @@ def date_string_to_iso_string(date_string: str):
 
 
 def string_to_float(raw_str: str):
+    if not raw_str or len(raw_str) < 1:
+        return raw_str
     if raw_str[0] == '$':
         raw_str = raw_str.replace('$', '')
 
@@ -104,10 +113,11 @@ class DecimalEncoder(json.JSONEncoder):
         return super(DecimalEncoder, self).default(o)
 
 
-def get_dynamo_items(table_name, table_filter=None, *args, **kwargs):
+def get_dynamo_items(table_name, table_filter=None, dynamodb_helper: DynamoHelperBase = EnvironmentControlledDynamoHelper(), *args, **kwargs):
     RETRY_EXCEPTIONS = ('ProvisionedThroughputExceededException',
                         'ThrottlingException')
-    table = dynamodb.Table(table_name)
+
+    table = dynamodb_helper.get_dynamo_db().Table(table_name)
 
     response = table.scan(**table_filter)
     items = response['Items']
@@ -152,3 +162,33 @@ def lat_long_distance(pointa, pointb):
     distance = R * c
 
     return distance
+
+
+def download_files(files=None, bucket_name=None):
+    try:
+        # Without providing explicit keys boto will pick up keys from the environment during dev,
+        # and pick up access control from the role in prod
+        # local file is ./aws/credentials see: https://docs.aws.amazon.com/cli/latest/userguide/cli-config-files.html
+        if not files:
+            files = []
+        data_dir = 'data/'
+        os.makedirs(data_dir, exist_ok=True)
+
+        local_files = []
+        for file in files:
+            os.makedirs(os.path.dirname(file), exist_ok=True)
+
+        for file in files:
+            local_file = file[file.rfind("/") + 1:]
+            local_file = data_dir + local_file
+
+            print('downloading:', file)
+            print('local_file:', local_file)
+            s3.Bucket(bucket_name).download_file(file, local_file)
+            local_files.append(local_file)
+
+        return local_files
+
+    except Exception as e:
+        print('exception', e)
+        print('traceback', traceback.format_exc())
